"""email_out: store raw text of composed message

Revision ID: 37bb3a9da25f
Revises: 69ac95aabb62
Create Date: 2025-12-02 19:53:10.108217

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '37bb3a9da25f'
down_revision = '69ac95aabb62'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('raw', sa.Text(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('raw')

    # ### end Alembic commands ###
