"""email_out: add success/failure columns

Revision ID: a78bce7efae8
Revises: ad0a51791468
Create Date: 2025-12-02 17:34:42.116274

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'a78bce7efae8'
down_revision = 'ad0a51791468'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('sent_successful', sa.JSON(), nullable=True))
        batch_op.add_column(sa.Column('sent_failed', sa.JSON(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('sent_failed')
        batch_op.drop_column('sent_successful')

    # ### end Alembic commands ###
