"""list: display nullable

Revision ID: e73f5a16f3fd
Revises: b092089c847f
Create Date: 2025-12-08 22:35:49.879535

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e73f5a16f3fd'
down_revision = 'b092089c847f'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('display',
               existing_type=sa.VARCHAR(),
               nullable=True)

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('list', schema=None) as batch_op:
        batch_op.alter_column('display',
               existing_type=sa.VARCHAR(),
               nullable=False)

    # ### end Alembic commands ###
