"""email_out: store subject of composed message

Revision ID: e88f8c7da784
Revises: 37bb3a9da25f
Create Date: 2025-12-02 20:00:16.259806

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e88f8c7da784'
down_revision = '37bb3a9da25f'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.add_column(sa.Column('subject', sa.String(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('email_out', schema=None) as batch_op:
        batch_op.drop_column('subject')

    # ### end Alembic commands ###
